EXPORTS
	??0TDiagnostic@@QAE@XZ @ 1 NONAME ; public: __thiscall TDiagnostic::TDiagnostic(void)
	??1CSDClientResult@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CSDClientResult::~CSDClientResult(void)
	??1CSDClientResultSet@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CSDClientResultSet::~CSDClientResultSet(void)
	??1CSDGrammar@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CSDGrammar::~CSDGrammar(void)
	??1CSDLexicon@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CSDLexicon::~CSDLexicon(void)
	??1CSDModel@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CSDModel::~CSDModel(void)
	??1CSDModelBank@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CSDModelBank::~CSDModelBank(void)
	??1CSDPronunciation@@UAE@XZ @ 8 NONAME ; public: virtual __thiscall CSDPronunciation::~CSDPronunciation(void)
	??1CSDResult@@UAE@XZ @ 9 NONAME ; public: virtual __thiscall CSDResult::~CSDResult(void)
	??1CSDResultSet@@UAE@XZ @ 10 NONAME ; public: virtual __thiscall CSDResultSet::~CSDResultSet(void)
	??1CSDRule@@UAE@XZ @ 11 NONAME ; public: virtual __thiscall CSDRule::~CSDRule(void)
	??1TDiagnostic@@QAE@XZ @ 12 NONAME ; public: __thiscall TDiagnostic::~TDiagnostic(void)
	?AcousticModel@CSDModel@@QBEABVTDesC8@@XZ @ 13 NONAME ; public: class TDesC8 const & __thiscall CSDModel::AcousticModel(void)const 
	?Add@CSDGrammar@@QAEHAAVCSDRule@@@Z @ 14 NONAME ; public: int __thiscall CSDGrammar::Add(class CSDRule &)
	?Add@CSDLexicon@@QAEHAAVCSDPronunciation@@@Z @ 15 NONAME ; public: int __thiscall CSDLexicon::Add(class CSDPronunciation &)
	?Add@CSDModelBank@@QAEHAAVCSDModel@@@Z @ 16 NONAME ; public: int __thiscall CSDModelBank::Add(class CSDModel &)
	?Add@CSDResultSet@@QAEHAAVCSDResult@@@Z @ 17 NONAME ; public: int __thiscall CSDResultSet::Add(class CSDResult &)
	?At@CSDClientResultSet@@QBEABVCSDClientResult@@H@Z @ 18 NONAME ; public: class CSDClientResult const & __thiscall CSDClientResultSet::At(int)const 
	?At@CSDGrammar@@QBEABVCSDRule@@H@Z @ 19 NONAME ; public: class CSDRule const & __thiscall CSDGrammar::At(int)const 
	?At@CSDLexicon@@QBEABVCSDPronunciation@@H@Z @ 20 NONAME ; public: class CSDPronunciation const & __thiscall CSDLexicon::At(int)const 
	?At@CSDModelBank@@QBEABVCSDModel@@H@Z @ 21 NONAME ; public: class CSDModel const & __thiscall CSDModelBank::At(int)const 
	?At@CSDResultSet@@QAEABVCSDResult@@H@Z @ 22 NONAME ; public: class CSDResult const & __thiscall CSDResultSet::At(int)
	?Count@CSDGrammar@@QBEHXZ @ 23 NONAME ; public: int __thiscall CSDGrammar::Count(void)const 
	?Count@CSDLexicon@@QBEHXZ @ 24 NONAME ; public: int __thiscall CSDLexicon::Count(void)const 
	?Count@CSDModelBank@@QBEHXZ @ 25 NONAME ; public: int __thiscall CSDModelBank::Count(void)const 
	?Count@CSDResultSet@@QBEHXZ @ 26 NONAME ; public: int __thiscall CSDResultSet::Count(void)const 
	?Delete@CSDGrammar@@QAEXK@Z @ 27 NONAME ; public: void __thiscall CSDGrammar::Delete(unsigned long)
	?Diagnostic@CSDClientResultSet@@QBEABVTDiagnostic@@XZ @ 28 NONAME ; public: class TDiagnostic const & __thiscall CSDClientResultSet::Diagnostic(void)const 
	?Diagnostic@CSDResultSet@@QBEABVTDiagnostic@@XZ @ 29 NONAME ; public: class TDiagnostic const & __thiscall CSDResultSet::Diagnostic(void)const 
	?E32Dll@@YAHW4TDllReason@@@Z @ 30 NONAME ; int __cdecl E32Dll(enum TDllReason)
	?FindModel@CSDModelBank@@QBEHK@Z @ 31 NONAME ; public: int __thiscall CSDModelBank::FindModel(unsigned long)const 
	?FindPronunciation@CSDLexicon@@QBEHK@Z @ 32 NONAME ; public: int __thiscall CSDLexicon::FindPronunciation(unsigned long)const 
	?FindRule@CSDGrammar@@QBEHK@Z @ 33 NONAME ; public: int __thiscall CSDGrammar::FindRule(unsigned long)const 
	?GrammarID@CSDClientResult@@QBEKXZ @ 34 NONAME ; public: unsigned long __thiscall CSDClientResult::GrammarID(void)const 
	?GrammarID@CSDGrammar@@QBEKXZ @ 35 NONAME ; public: unsigned long __thiscall CSDGrammar::GrammarID(void)const 
	?GrammarID@CSDResult@@QBEKXZ @ 36 NONAME ; public: unsigned long __thiscall CSDResult::GrammarID(void)const 
	?LexiconID@CSDLexicon@@QBEKXZ @ 37 NONAME ; public: unsigned long __thiscall CSDLexicon::LexiconID(void)const 
	?LexiconID@CSDRule@@QBEKXZ @ 38 NONAME ; public: unsigned long __thiscall CSDRule::LexiconID(void)const 
	?MaxResults@CSDClientResultSet@@QBEHXZ @ 39 NONAME ; public: int __thiscall CSDClientResultSet::MaxResults(void)const 
	?ModelBankID@CSDModelBank@@QBEKXZ @ 40 NONAME ; public: unsigned long __thiscall CSDModelBank::ModelBankID(void)const 
	?ModelBankID@CSDPronunciation@@QBEKXZ @ 41 NONAME ; public: unsigned long __thiscall CSDPronunciation::ModelBankID(void)const 
	?NewL@CSDClientResult@@SAPAV1@KK@Z @ 42 NONAME ; public: static class CSDClientResult * __cdecl CSDClientResult::NewL(unsigned long,unsigned long)
	?NewL@CSDClientResult@@SAPAV1@XZ @ 43 NONAME ; public: static class CSDClientResult * __cdecl CSDClientResult::NewL(void)
	?NewL@CSDClientResultSet@@SAPAV1@XZ @ 44 NONAME ; public: static class CSDClientResultSet * __cdecl CSDClientResultSet::NewL(void)
	?NewL@CSDGrammar@@SAPAV1@K@Z @ 45 NONAME ; public: static class CSDGrammar * __cdecl CSDGrammar::NewL(unsigned long)
	?NewL@CSDLexicon@@SAPAV1@K@Z @ 46 NONAME ; public: static class CSDLexicon * __cdecl CSDLexicon::NewL(unsigned long)
	?NewL@CSDModel@@SAPAV1@K@Z @ 47 NONAME ; public: static class CSDModel * __cdecl CSDModel::NewL(unsigned long)
	?NewL@CSDModel@@SAPAV1@XZ @ 48 NONAME ; public: static class CSDModel * __cdecl CSDModel::NewL(void)
	?NewL@CSDModelBank@@SAPAV1@K@Z @ 49 NONAME ; public: static class CSDModelBank * __cdecl CSDModelBank::NewL(unsigned long)
	?NewL@CSDPronunciation@@SAPAV1@KKK@Z @ 50 NONAME ; public: static class CSDPronunciation * __cdecl CSDPronunciation::NewL(unsigned long,unsigned long,unsigned long)
	?NewL@CSDResult@@SAPAV1@KK@Z @ 51 NONAME ; public: static class CSDResult * __cdecl CSDResult::NewL(unsigned long,unsigned long)
	?NewL@CSDResult@@SAPAV1@XZ @ 52 NONAME ; public: static class CSDResult * __cdecl CSDResult::NewL(void)
	?NewL@CSDResultSet@@SAPAV1@XZ @ 53 NONAME ; public: static class CSDResultSet * __cdecl CSDResultSet::NewL(void)
	?NewL@CSDRule@@SAPAV1@KKK@Z @ 54 NONAME ; public: static class CSDRule * __cdecl CSDRule::NewL(unsigned long,unsigned long,unsigned long)
	?NewLC@CSDClientResult@@SAPAV1@KK@Z @ 55 NONAME ; public: static class CSDClientResult * __cdecl CSDClientResult::NewLC(unsigned long,unsigned long)
	?NewLC@CSDClientResult@@SAPAV1@XZ @ 56 NONAME ; public: static class CSDClientResult * __cdecl CSDClientResult::NewLC(void)
	?NewLC@CSDClientResultSet@@SAPAV1@XZ @ 57 NONAME ; public: static class CSDClientResultSet * __cdecl CSDClientResultSet::NewLC(void)
	?NewLC@CSDGrammar@@SAPAV1@K@Z @ 58 NONAME ; public: static class CSDGrammar * __cdecl CSDGrammar::NewLC(unsigned long)
	?NewLC@CSDLexicon@@SAPAV1@K@Z @ 59 NONAME ; public: static class CSDLexicon * __cdecl CSDLexicon::NewLC(unsigned long)
	?NewLC@CSDModel@@SAPAV1@K@Z @ 60 NONAME ; public: static class CSDModel * __cdecl CSDModel::NewLC(unsigned long)
	?NewLC@CSDModel@@SAPAV1@XZ @ 61 NONAME ; public: static class CSDModel * __cdecl CSDModel::NewLC(void)
	?NewLC@CSDModelBank@@SAPAV1@K@Z @ 62 NONAME ; public: static class CSDModelBank * __cdecl CSDModelBank::NewLC(unsigned long)
	?NewLC@CSDPronunciation@@SAPAV1@KKK@Z @ 63 NONAME ; public: static class CSDPronunciation * __cdecl CSDPronunciation::NewLC(unsigned long,unsigned long,unsigned long)
	?NewLC@CSDResult@@SAPAV1@KK@Z @ 64 NONAME ; public: static class CSDResult * __cdecl CSDResult::NewLC(unsigned long,unsigned long)
	?NewLC@CSDResult@@SAPAV1@XZ @ 65 NONAME ; public: static class CSDResult * __cdecl CSDResult::NewLC(void)
	?NewLC@CSDResultSet@@SAPAV1@XZ @ 66 NONAME ; public: static class CSDResultSet * __cdecl CSDResultSet::NewLC(void)
	?NewLC@CSDRule@@SAPAV1@KKK@Z @ 67 NONAME ; public: static class CSDRule * __cdecl CSDRule::NewLC(unsigned long,unsigned long,unsigned long)
	?PhonemeID@CSDModel@@QBEKXZ @ 68 NONAME ; public: unsigned long __thiscall CSDModel::PhonemeID(void)const 
	?PhonemeID@CSDPronunciation@@QBEKXZ @ 69 NONAME ; public: unsigned long __thiscall CSDPronunciation::PhonemeID(void)const 
	?PronunciationID@CSDPronunciation@@QBEKXZ @ 70 NONAME ; public: unsigned long __thiscall CSDPronunciation::PronunciationID(void)const 
	?PronunciationID@CSDRule@@QBEKXZ @ 71 NONAME ; public: unsigned long __thiscall CSDRule::PronunciationID(void)const 
	?ResultCount@CSDClientResultSet@@QBEHXZ @ 72 NONAME ; public: int __thiscall CSDClientResultSet::ResultCount(void)const 
	?RuleID@CSDClientResult@@QBEKXZ @ 73 NONAME ; public: unsigned long __thiscall CSDClientResult::RuleID(void)const 
	?RuleID@CSDResult@@QBEKXZ @ 74 NONAME ; public: unsigned long __thiscall CSDResult::RuleID(void)const 
	?RuleID@CSDRule@@QBEKXZ @ 75 NONAME ; public: unsigned long __thiscall CSDRule::RuleID(void)const 
	?Score@CSDResult@@QBEJXZ @ 76 NONAME ; public: long __thiscall CSDResult::Score(void)const 
	?SetAcousticModel@CSDModel@@QAEXAAVTPtr8@@@Z @ 77 NONAME ; public: void __thiscall CSDModel::SetAcousticModel(class TPtr8 &)
	?SetDiagnostic@CSDClientResultSet@@QAEXAAVTDiagnostic@@@Z @ 78 NONAME ; public: void __thiscall CSDClientResultSet::SetDiagnostic(class TDiagnostic &)
	?SetDiagnostic@CSDResultSet@@QAEXAAVTDiagnostic@@@Z @ 79 NONAME ; public: void __thiscall CSDResultSet::SetDiagnostic(class TDiagnostic &)
	?SetGrammarID@CSDClientResult@@QAEXK@Z @ 80 NONAME ; public: void __thiscall CSDClientResult::SetGrammarID(unsigned long)
	?SetGrammarID@CSDResult@@QAEXK@Z @ 81 NONAME ; public: void __thiscall CSDResult::SetGrammarID(unsigned long)
	?SetMaxResultsL@CSDClientResultSet@@QAEXH@Z @ 82 NONAME ; public: void __thiscall CSDClientResultSet::SetMaxResultsL(int)
	?SetPhonemeID@CSDModel@@QAEXK@Z @ 83 NONAME ; public: void __thiscall CSDModel::SetPhonemeID(unsigned long)
	?SetResultCount@CSDClientResultSet@@QAEXH@Z @ 84 NONAME ; public: void __thiscall CSDClientResultSet::SetResultCount(int)
	?SetRuleID@CSDClientResult@@QAEXK@Z @ 85 NONAME ; public: void __thiscall CSDClientResult::SetRuleID(unsigned long)
	?SetRuleID@CSDResult@@QAEXK@Z @ 86 NONAME ; public: void __thiscall CSDResult::SetRuleID(unsigned long)
	?SetScore@CSDResult@@QAEXJ@Z @ 87 NONAME ; public: void __thiscall CSDResult::SetScore(long)
	?ExternalizeL@CSDClientResultSet@@QBEXAAVRWriteStream@@@Z @ 88 NONAME ; public: void __thiscall CSDClientResultSet::ExternalizeL(class RWriteStream &)const 
	?InternalizeL@CSDClientResultSet@@QAEXAAVRReadStream@@@Z @ 89 NONAME ; public: void __thiscall CSDClientResultSet::InternalizeL(class RReadStream &)
